/*
 * Example for Step-up click
 *
 * Date         Apr 2017
 * Author       Djordje Rosic
 *
 * Test configuration PIC32 :
 *  MCU           :        P32MX795F512L
 *  Dev. Board    :        EasyPIC Fusion v7
 *  SW            :        mikroC PRO for PIC32 v3.6.1
 *
 * Description :
 *
 *    Connect the click to the input power supply (2.5V - 4.5V). This example
 *    shows how to set the desired output voltage, by cycling through a couple
 *    of predefined voltage values.
 *
 ******************************************************************************/
sbit CS_PIN at LATC2_bit;
sbit CS_PIN_DIR at TRISC2_bit;
/*
 * System Initialization
 */
void systemInit()
{
    CS_PIN_DIR = 0;

     /*Initializes SPI interface*/
    SPI3_Init_Advanced(_SPI_MASTER, _SPI_8_BIT, 256, _SPI_SS_DISABLE,
     _SPI_DATA_SAMPLE_MIDDLE, _SPI_CLK_IDLE_HIGH, _SPI_ACTIVE_2_IDLE);


    /*Sets chip select to inactive*/
    CS_PIN = 1;

    delay_ms(3000);

}
void main() 
{
    systemInit();

    while (1)
    {
        delay_ms(3000);
        //Sets the voltage to VOUTmax, ~5.25 V
        CS_PIN = 0;       //Sets chip select to active
        delay_us( 10 );
        Spi3_Write(0b01110000);
        Spi3_Write(0b00000000);
        CS_PIN = 1;       //Sets chip select to inactive

        delay_ms(3000);
        //Sets the voltage to VOUTmin, which depends on VIN, but cannot
        //be lower than 2.50 V
        CS_PIN = 0;       //Sets chip select to active
        delay_us( 10 );
        Spi3_Write(0b01111111);
        Spi3_Write(0b11111111);
        CS_PIN = 1;       //Sets chip select to inactive
        
        delay_ms(3000);
        //Sets the voltage ~4.0 V
        CS_PIN = 0;       //Sets chip select to active
        delay_us( 10 );
        Spi3_Write(0b01110111);
        Spi3_Write(0b01000000);
        CS_PIN = 1;       //Sets chip select to inactive

        delay_ms(3000);
        //Sets the voltage ~4.5 V
        CS_PIN = 0;       //Sets chip select to active
        delay_us( 10 );
        Spi3_Write(0b01110100);
        Spi3_Write(0b00011111);
        CS_PIN = 1;       //Sets chip select to inactive
    }
}

/************************************************************ END OF FILE *****/